/**
 * @file Ce fichier contient les tests des resolvers des groupes
 * @author ofacklam
*/

import { TestSet } from '../../testData';

export const tests : TestSet = {
    description: "Group type resolvers",
    tests: [
        {
            description: "group(gid) bad gid",
            query: `
            query {
                group(gid:"nonexistent") {
                    gid
                }
            }
            `,
            result: {
                "data": {
                    "group": null
                }
            }
        },

        {
            description: "group(gid) with simplegroup",
            query: `
            query {
                group(gid:"br") {
                    gid
                }
            }
            `,
            result: {
                "data": {
                    "group": {
                        "gid": "br"
                    }
                } 
            }
        },

        {
            description: "group(gid) with uncached simplegroup",
            query: `
            query {
                group(gid:"bda") {
                    gid
                }
            }
            `,
            result: {
                "data": {
                    "group": {
                        "gid": "bda"
                    }
                }
            }
        },

        {
            description: "group(gid) with metagroup",
            query: `
            query {
                group(gid:"federez") {
                    gid
                }
            }
            `,
            result: {
                "data": {
                    "group": {
                        "gid": "federez"
                    }
                }
            }
        },

        {
            description: "simpleGroup(gid) bad gid",
            query: `
            query {
                simpleGroup(gid:"federez") {
                    gid
                }
            }
            `,
            result: {
                "data": {
                    "simpleGroup": null
                }
            }
        },

        {
            description: "simpleGroup(gid)",
            query: `
            query {
                simpleGroup(gid:"br") {
                    gid
                }
            }
            `,
            result: {
                "data": {
                    "simpleGroup": {
                        "gid": "br"
                    }
                }
            }
        },

        {
            description: "metaGroup(gid) bad gid",
            query: `
            query {
                metaGroup(gid:"br") {
                    gid
                }
            }
            `,
            result: {
                "data": {
                    "metaGroup": null
                }
            }
        },

        {
            description: "metaGroup(gid)",
            query: `
            query {
                metaGroup(gid:"federez") {
                    gid
                }
            }
            `,
            result: {
                "data": {
                    "metaGroup": {
                        "gid": "federez"
                    }
                }
            }
        }
    ]
}
