/**
 * @file Ce fichier contient les tests des resolvers des users
 * @author ofacklam
*/

import { TestSet } from '../../testData';

export const tests: TestSet = {
    description: "User type resolvers",
    tests: [
        {
            description: "user(uid)",
            query: `
                query {
                    user(uid: "oliver.facklam") {
                        uid
                    }
                }
            `,
            result: {
                "data": {
                    "user": {
                        "uid": "oliver.facklam"
                    }
                }
            }
        },

        {
            description: "user(uid) bad uid",
            query: `
                query {
                    user(uid: "non.existant") {
                        uid
                    }
                }
            `,
            result: {
                "data": {
                    "user": null
                }
            }
        },

        {
            description: "searchTOL(givenName)",
            query: `
                query {
                    searchTOL(givenName: "Olivér") {
                        uid
                    }
                }
            `,
            result: {
                "data": {
                    "searchTOL": [
                        {
                            "uid": "oliver.facklam"
                        }
                    ]
                }
            }
        },

        {
            description: "searchTOL(lastName) partial",
            query: `
                query {
                    searchTOL(lastName: "Fack") {
                        uid
                    }
                }
            `,
            result: {
                "data": {
                    "searchTOL": [
                        {
                            "uid": "hugues.asofa-zeufack"
                        },
                        {
                            "uid": "fabrice.zapfack"
                        },
                        {
                            "uid": "jordan.lekeufack-sopze"
                        },
                        {
                            "uid": "oliver.facklam"
                        }
                    ]
                }
            }
        },

        /*{
            description: "searchTOL(groups) triclassés",
            query: `
                query {
                    searchTOL(groups: ["br", "faerix", "jtx"]) {
                        uid
                    }
                }
            `,
            result: {
                "data": {
                    "searchTOL": [
                        {
                            "uid": "dubut.2003"
                        },
                        {
                            "uid": "brodard.2004"
                        },
                        {
                            "uid": "le-floch.2004"
                        },
                        {
                            "uid": "rabie.2004"
                        },
                        {
                            "uid": "pierre-etienne.marx"
                        },
                        {
                            "uid": "lauriane.aufrant"
                        },
                        {
                            "uid": "matthias.bry"
                        },
                        {
                            "uid": "julia.chatain"
                        },
                        {
                            "uid": "victor.berger"
                        },
                        {
                            "uid": "augustin.lenormand"
                        },
                        {
                            "uid": "timothee.darcet"
                        }
                    ]
                }
            }
        },*/

        {
            description: "dislikes not authorized",
            query: `
                query {
                    dislikes {
                        gid
                    }
                }
            `,
            result: {
                "data": {
                    "dislikes": null
                }
            }
        },

        {
            description: "firstName, lastName, nickName",
            query: `
                query {
                    user(uid: "oliver.facklam") {
                        givenName
                        lastName
                        nickname
                    }
                }
            `,
            result: {
                "data": {
                    "user": {
                        "givenName": "Olivér",
                        "lastName": "Facklam",
                        "nickname": null
                    }
                }
            }
        },   
        
        {
            description: "nationality, birthdate",
            query: `
                query {
                    user(uid: "timothee.darcet") {
                        nationality,
                        birthdate
                    }
                }
            `,
            result: {
                "data": {
                    "user": {
                        "nationality": "Française",
                        "birthdate": "1998-05-27"
                    }
                }
            }
        },

        {
            description: "photo, mail",
            query: `
                query {
                    user(uid: "oliver.facklam") {
                        photo,
                        mail,
                    }
                }

            `,
            result: {
                "data": {
                    "user": {
                        "photo": "https://www.frankiz.net/image/full/40596",
                        "mail": "oliver.facklam@polytechnique.edu"
                    }
                }
            }
        },

        {
            description: "inheritedMemberOf",
            query: `
                query {
                    user(uid: "oliver.facklam") {
                        inheritedMemberOf {
                            gid
                        }
                    }
                }
            `,
            result: {
                "data": {
                    "user": {
                        "inheritedMemberOf": [
                            {
                                "gid": "br"
                            },
                            {
                                "gid": "faerix"
                            },
                            {
                                "gid": "xy"
                            },
                            {
                                "gid": "chorale"
                            },
                            {
                                "gid": "subaisse"
                            },
                            {
                                "gid": "sport_judo"
                            },
                            {
                                "gid": "on_platal"
                            },
                            {
                                "gid": "formation_x"
                            },
                            {
                                "gid": "promo_2017"
                            },
                            {
                                "gid": "promo_x2017"
                            },
                            {
                                "gid": "groupe_sigma"
                            },
                            {
                                "gid": "root_br"
                            },
                            {
                                "gid": "artificial_intelligence"
                            },
                            {
                                "gid": "federez"
                            }
                        ]
                    }
                }
            }
        },

        {
            description: "speakerOf",
            query: `
                query {
                    user(uid: "oliver.facklam") {
                        speakerOf {
                            gid
                        }
                    }
                }
            `,
            result: {
                "data": {
                    "user": {
                        "speakerOf": [
                            {
                                "gid": "groupe_sigma"
                            }
                        ]
                    }
                }
            }
        },

        {
            description: "inheritedAdminOf",
            query: `
                query {
                    user(uid: "oliver.facklam") {
                        inheritedAdminOf {
                            gid
                        }
                    }
                }
            `,
            result: {
                "data": {
                    "user": {
                        "inheritedAdminOf": [
                            {
                                "gid": "groupe_sigma"
                            }
                        ]
                    }
                }
            }
        },

        {
            description: "likes",
            query: `
                query {
                    user(uid: "timothee.darcet") {
                        likes {
                            gid
                        }
                    }
                }
            `,
            result: {
                "data": {
                    "user": {
                        "likes": [
                            {
                                "gid": "impro"
                            },
                            {
                                "gid": "montagne"
                            },
                            {
                                "gid": "x-courseaularge"
                            },
                            {
                                "gid": "wep"
                            },
                            {
                                "gid": "xonthemun"
                            },
                            {
                                "gid": "skiclub"
                            },
                            {
                                "gid": "bspp"
                            },
                            {
                                "gid": "ratemyclass"
                            },
                            {
                                "gid": "ratatouille"
                            },
                            {
                                "gid": "badas"
                            },
                            {
                                "gid": "aventuriers"
                            },
                            {
                                "gid": "cordix"
                            },
                            {
                                "gid": "ionsat"
                            }
                        ]
                    }
                }
            }
        },

        {
            description: "questionsFromUser empty (only for viewers of groups)",
            query: `
                query {
                    user(uid: "timothee.darcet") {
                        questionsFromUser {
                            title
                            content
                        }
                    }
                }
            `,
            result: {
                "data": {
                    "user": {
                        "questionsFromUser": []
                    }
                }
            }
        },
    ]
}